@@ -162,11 +162,15 @@ def get_monitoring_services(request):
 
 
 def show_by_dimension(data, dim_name):
-    if 'dimensions' in data['metrics'][0]:
-        dimensions = data['metrics'][0]['dimensions']
-        if dim_name in dimensions:
-            return str(data['metrics'][0]['dimensions'][dim_name].encode('utf-8'))
-    return ""
+    if 'metrics' in data:
+        dimensions = []
+        for metric in data['metrics']:
+            if 'dimensions' in metric:
+                if dim_name in metric['dimensions']:
+                    dimensions.append(str(metric['dimensions'][dim_name].encode('utf-8')))
+
+        return dimensions
+    return []
 
 
 def get_status(alarms):
@@ -198,10 +202,11 @@ def generate_status(request):
         if 'groupBy' in row:
             alarms_by_group = {}
             for a in alarms:
-                group = show_by_dimension(a, row['groupBy'])
-                if group:
-                    group_alarms = alarms_by_group.setdefault(group, [])
-                    group_alarms.append(a)
+                groups = show_by_dimension(a, row['groupBy'])
+                if groups:
+                    for group in groups:
+                        group_alarms = alarms_by_group.setdefault(group, [])
+                        group_alarms.append(a)
             services = []
             for group, group_alarms in alarms_by_group.items():
                 name = '%s=%s' % (row['groupBy'], group)
@@ -261,7 +266,9 @@ class MonascaProxyView(TemplateView):
             dimensions_str = req_kwargs['dimensions'][0]
             dimensions_str_array = dimensions_str.split(',')
             for dimension in dimensions_str_array:
-                dimension_name_value = dimension.split(':')
+                # limit splitting since value may contain a ':' such as in
+                # the `url` dimension of the service_status check.
+                dimension_name_value = dimension.split(':', 1)
                 if len(dimension_name_value) == 2:
                     name = dimension_name_value[0].encode('utf8')
                     value = dimension_name_value[1].encode('utf8')
